
--[[ Copyright (c) 2014 Lars Lönneker

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE. --]]


-- AIR TAXI --
--------------
sti = require("source.STI")
HC = require("source.HC")
require("source.Common")
require("source.Animation")

-- Settings --
love.graphics.setDefaultFilter("nearest", "nearest")
VERSION = "0.2"
CURRENT_INPUT_DEVICE = "keyboard"
FONT = {small = love.graphics.newFont("assets/font.ttf", 8),
medium = love.graphics.newFont("assets/font.ttf", 13)}

-- Dependencies --
local Fader = require("source.Fader")
local SceneManager = require("source.SceneManager")
local SplashScene = require("source.SplashScene")
local MenuScene = require("source.MenuScene")
local SettingsScene = require("source.SettingsScene")
local GameScene = require("source.GameScene")


function setWindow()
  -- Initialize window
  love.window.setTitle("Air Taxi "..VERSION)
  WIDTH, HEIGHT = 320, 180 -- Window dimensions
  if love.system.getOS() == "Windows" then
    love.window.setMode(WIDTH*SCREENMULTIPLIER, HEIGHT*SCREENMULTIPLIER, {vsync = VSYNC, fullscreen = FULLSCREEN, fullscreentype = "normal"})
  else
    love.window.setMode(WIDTH*SCREENMULTIPLIER, HEIGHT*SCREENMULTIPLIER, {vsync = VSYNC, fullscreen = FULLSCREEN, fullscreentype = "desktop"})
  end
  
  -- Set Resolution
  setResolution(WIDTH, HEIGHT)
end


function love.load() 
  -- Setup stuff
  CONTROLLER = {}
  VOLUME = .4
  love.audio.setVolume(VOLUME)
  
  -- Screen Settings
  SCREENMULTIPLIER = 3
  VSYNC, FULLSCREEN = false, false
  setWindow()
  
  -- Create a random seed
  math.randomseed(os.time())
  
  -- Setup scenes
  SceneManager.newScene(SplashScene, "SplashScene")
  SceneManager.newScene(MenuScene, "MenuScene")
  SceneManager.newScene(SettingsScene, "SettingsScene")
  SceneManager.newScene(GameScene, "GameScene")
  SceneManager.setScene("MenuScene")
end


function love.update(dt)
  SceneManager.update(dt)
  Fader.update(dt)
end


function love.draw()
  love.graphics.scale(SCALEX, SCALEY)
  SceneManager.draw()
  Fader.draw()
  --love.graphics.print("FPS: "..love.timer.getFPS(), 10, 10)
end


function love.keypressed(key)
  CURRENT_INPUT_DEVICE = "keyboard"
  SceneManager.keypressed(key)
end


function love.joystickpressed(joystick, button)
  CURRENT_INPUT_DEVICE = "joystick"
  SceneManager.joystickpressed(joystick, button)
end


function love.joystickaxis(joystick, axis)
  SceneManager.joystickaxis(joystick, axis)
end


function love.joystickadded(joystick)
  CONTROLLER[joystick:getID()] = joystick
end


function love.joystickremoved(joystick)
  CURRENT_INPUT_DEVICE = "keyboard"
  CONTROLLER[joystick:getID()] = nil
end
