
-------------------------
-- // ButtonManager \\ --
-------------------------

local ButtonManager = {}
ButtonManager.__index = ButtonManager

-- Dependencies --
local Button = require("source.Button")
local nextButton = love.audio.newSource("assets/nextButton.ogg", "static")

function ButtonManager:new()
  local self = setmetatable({}, ButtonManager)
  self.buttons = {}
  self.selectedButton = 1
  return self
end


function ButtonManager:setSelected(button)
  self.selectedButton = button
  self.buttons[button].selected = true
end


function ButtonManager:newButton(name, x, y, action)
  local button = Button:new(name, x, y, action)
  table.insert(self.buttons, button)
end


function ButtonManager:getArray()
  return self.buttons
end


function ButtonManager:clear()
  self.buttons = {}
end


function ButtonManager:update(dt)
  for k, button in ipairs(self.buttons) do
    button:update(dt)
  end
  self.buttons[self.selectedButton].selected = true
end


function ButtonManager:draw()
  for k, button in ipairs(self.buttons) do
    button:draw()
  end
end


function ButtonManager:itemUp()
  if self.selectedButton > 1 then
   for i, button in ipairs(self.buttons) do button.selected = false end
    self.selectedButton = self.selectedButton-1
    --nextButton:stop()
    --nextButton:play()
    self.buttons[self.selectedButton].selected = true
  end
end

function ButtonManager:itemDown()
  if self.selectedButton < #self.buttons then
    for i, button in ipairs(self.buttons) do button.selected = false end
    self.selectedButton = self.selectedButton+1
    --nextButton:stop()
    --nextButton:play()
    self.buttons[self.selectedButton].selected = true
  end
end


function ButtonManager:itemAction(direction)
  if self.buttons[self.selectedButton].action then
    self.buttons[self.selectedButton].action(direction)
  end
end

return ButtonManager
