
-- Game Scene --
----------------
local GameScene = {}

-- Dependencies --
------------------
local Level = require("source.Level")
local Ui = require("source.Ui")
local Taxi = require("source.Taxi")
local City = require("source.City")
local Fader = require("source.Fader")
local SceneManager = require("source.SceneManager")

-- Declarations --
------------------
local map
local taxiArray = {}

function GameScene:init()
  Level:init()
  self.level = 1
end


function GameScene:enter()
  self.paused = false
  map = Level:setLevel(self.level)
  local gasstation = Level:getPad("Gas Station")
  if not player or player.lives < 1 then
    taxiArray[1] = Taxi:new(gasstation.x + gasstation.w / 2 - 16, gasstation.y - 10)
    player = taxiArray[1]
  else
    player:respawn(gasstation.x + gasstation.w / 2 - 16, gasstation.y - 10)
  end
  
  Ui:init()
  City:init()
end


function GameScene:leave()
  SceneManager.getArray("MenuScene"):renderCanvas(true)
end


function GameScene:update(dt)
  
  -- Level progress --
  --------------------
  if map.completed then
    self.level = self.level + 1
    if love.filesystem.exists("assets/level"..self.level..".lua") then Fader.fadeTo("GameScene")
    else Fader.fadeTo("MenuScene") end
    player:hide()
    map.completed = false
  end
  
  -- Update everything --
  -----------------------
  if not self.paused then
    City:update(dt)
   if not player.removed then player:update(dt)
   else table.remove(taxiArray, 1) end
    Level:update(dt)
    Ui:update(dt)
    
    -- Passenger --
    for i, passenger in ipairs(Level.passengers) do
      if not passenger.removed then passenger:update(dt)
      else table.remove(Level.passengers, i) end
    end
  
    -- Gravity Balls --
    for i, gravityBall in ipairs(Level.gravityBalls) do
      gravityBall:update(dt)
    end
  end

end


function GameScene:draw()
  -- Draw Map --
  map:drawTileLayer("bg")
  City:draw()
  map:drawTileLayer("level")
  if map.layers["exit"].visible then map:drawTileLayer("exit") end
  
  map:drawTileLayer("objects")
  
  -- Draw Passengers --
  for i, passenger in ipairs(Level.passengers) do
    passenger:draw()
  end
  
  -- Draw Gravity Balls --
  for i, gravityBall in ipairs(Level.gravityBalls) do
    gravityBall:draw()
  end
  
  Level:draw()
  if not player.removed then player:draw() end
  Ui:draw()
  
  if self.paused then printFont(FONT.small, "PAUSED", WIDTH / 2 - FONT.small:getWidth("PAUSED")/2, HEIGHT / 2 - FONT.small:getHeight()/2) end
end


function GameScene:keypressed(key)
  player:keypressed(key)
  if key == "escape" then SceneManager.setScene("MenuScene") end
  if key == "r" then
    local gasstation = Level:getPad("Gas Station")
    Fader.fadeTo("GameScene", 400, function() player = Taxi:new(gasstation.x + gasstation.w / 2 - 16, gasstation.y - 10) end)
    self.level = 1
  end
  if key == "p" then self.paused = not self.paused end
end


function GameScene:joystickpressed(joystick, button)
  player:joystickpressed(joystick, button)
  if CONTROLLER[1]:isGamepadDown("b") then SceneManager.setScene("MenuScene") end
  if CONTROLLER[1]:isGamepadDown("back") then
    local gasstation = Level:getPad("Gas Station")
    Fader.fadeTo("GameScene", 400, function() player = Taxi:new(gasstation.x + gasstation.w / 2 - 16, gasstation.y - 10) end)
    self.level = 1
  end
  if CONTROLLER[1]:isGamepadDown("start") then self.paused = not self.paused end
end


return GameScene
