

-- // GravityBall \\ --
-----------------------
local Object = require("source.Object")
local GravityBall = Object:new()
GravityBall.__index = GravityBall

-- Dependencies --
------------------
--local Level = require("source.Level")

-- Declarations --
------------------
local images = {
  love.graphics.newImage("assets/gravityBall1.png"),
}

local function boxCollision(a, b)
  return a.x + a.w > b.x and a.x < b.x + b.w
  and a.y + a.h > b.y and a.y < b.y + b.h
end



function GravityBall:new(x, y, direction, speed)
  local self = setmetatable({}, GravityBall)
  self.velX = 0
  self.velY = 0
  self.direction = direction
  if self.direction == "up" then
    self.image = images[1]
    self.velY = -speed
  elseif self.direction == "down" then
    self.image = images[1]
    self.velY = speed
  elseif self.direction == "left" then
    self.image = images[1]
    self.velX = -speed
  elseif self.direction == "right" then
    self.image = images[1]
    self.velX = speed
  else self.velX = 0 ; self.velY = 0 end
  self.w = self.image:getWidth()
  self.h = self.image:getHeight()
  self.x = x
  self.y = y
  self.timer = math.random(1, 10)
  return self
end


function GravityBall:update(dt)
  self.timer = self.timer + dt
  local tweenX = math.sin(self.timer*6)*16 * dt
  local tweenY = math.cos(self.timer*6)*16 * dt
  if self.direction == "up" or self.direction == "down" then self.x = self.x + tweenX + self.velX  * dt
  else self.x = self.x + self.velX  * dt end
  if self.direction == "left" or self.direction == "right" then self.y = self.y + tweenY + self.velY  * dt
  else self.y = self.y + self.velY  * dt end
  
  if self.x < -self.w then self.x = WIDTH
  elseif self.x > WIDTH then self.x = -self.w
  elseif self.y < -self.h then self.x = HEIGHT
  elseif self.y > HEIGHT then self.y = -self.h end

  if boxCollision(self, player) then
    player.velY = player.velY + 75 * dt
  end
end


function GravityBall:draw()
  love.graphics.setScissor(0, 0, WIDTH*SCALEX, HEIGHT*SCALEY-64)
  if self.direction == "up" then love.graphics.draw(self.image, self.x, self.y, 0, 1, -1, 0, self.h)
  elseif self.direction == "left" then love.graphics.draw(self.image, self.x, self.y, 0, -1, 1, self.w)
  else love.graphics.draw(self.image, self.x, self.y) end
  love.graphics.setScissor()
end

return GravityBall
