
-- Mainmenu Scene --
--------------------
local MenuScene = {}

-- Dependencies --
------------------
local SceneManager = require("source.SceneManager")
local ButtonManager = require("source.ButtonManager")
local City = require("source.City")
local Button = require("source.Button")
local Fader = require("source.Fader")

-- Declarations --
------------------
local map
local titleTimer = 0
local overlay = love.graphics.newImage("assets/menuOverlay.png")
local title = {}
title.image = love.graphics.newImage("assets/title.png")
title.w = title.image:getWidth()
title.h = title.image:getHeight()
title.canvas = love.graphics.newCanvas(WIDTH, HEIGHT)
title.textw = FONT.small:getWidth("Version "..VERSION)

function MenuScene:init()
  -- Show splash
  SceneManager.setOverlay("SplashScene")
  
  -- title canvas --
  self:renderCanvas()
  
  -- Create ButtonManager --
  self.buttonManager = ButtonManager:new()
end


function MenuScene:renderCanvas(scale)
  title.canvas:clear()
  love.graphics.setCanvas(title.canvas)
  if scale then love.graphics.scale(1/SCALEX, 1/SCALEY) end
  love.graphics.draw(title.image, WIDTH / 2 - title.w / 2, 32) 
  printFontCentered(FONT.small, "Version "..VERSION, WIDTH / 2 - title.textw / 2, 32 + title.h+FONT.small:getHeight() / 2, title.textw) 
  love.graphics.setCanvas()
end


function MenuScene:enter()
  
  -- Reset stuff
  SceneManager.getArray("GameScene").level = 1
  player = nil
  
  -- Load
  map = sti.new("assets/menu")
  City:init()
  
  -- Create Buttons
  self.buttonManager:clear()
  self.buttonManager:newButton("Play", WIDTH / 2, HEIGHT / 2, function() Fader.fadeTo("GameScene", 350) end)
  self.buttonManager:newButton("Settings", WIDTH / 2, HEIGHT / 2 + 10*1, function() SceneManager.setOverlay("SettingsScene") end)
  self.buttonManager:newButton("Credits", WIDTH / 2, HEIGHT / 2 + 10*2)
  self.buttonManager:newButton("Exit", WIDTH / 2, HEIGHT / 2 + 10*3, function() love.event.quit() end)
  self.buttonManager:setSelected(1)
end


function MenuScene:leave()
end


function MenuScene:update(dt)
  City:update(dt)
  self.buttonManager:update(dt)
end


function MenuScene:draw()
  map:drawTileLayer("bg")
  City:draw()
  love.graphics.draw(overlay, 0, 0)
  if SceneManager.getOverlay() == "SettingsScene" then return end
  local dt = love.timer.getDelta()
  titleTimer = titleTimer + dt
  local tweeny = math.cos(titleTimer*4)*1
  love.graphics.draw(title.canvas, 0, tweeny)
  self.buttonManager:draw()
end


function MenuScene:keypressed(key)
  if SceneManager.getOverlay() ~= nil then return end
  if key == "up" then self.buttonManager:itemUp() end
  if key == "down" then self.buttonManager:itemDown() end
  if key == "return"  then self.buttonManager:itemAction() end
  if key == "escape" then love.event.quit() end
end


function MenuScene:joystickpressed(joystick, button)
  if SceneManager.getOverlay() ~= nil then return end
  if CONTROLLER[1]:isGamepadDown("b") then love.event.quit() end
  if CONTROLLER[1]:isGamepadDown("a") then self.buttonManager:itemAction() end
  if CONTROLLER[1]:isGamepadDown("dpup") then self.buttonManager:itemUp() end
  if CONTROLLER[1]:isGamepadDown("dpdown") then self.buttonManager:itemDown() end
end

return MenuScene
