------------------------
-- // SceneManager \\ --
------------------------

--[[
Copyright (c) 2013 Lars Lönneker

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
--]]

------------------------
-- // Declarations \\ --
------------------------
local SceneManager        = {}
local _scenes             = {}
local _overlay, _currentScene, _mode
-- local callbacks = {"keypressed", "keyreleased", "mousepressed", "mousereleased", "joystickpressed", "joystickreleased"}

local function initScene(scene)
  if not scene.loaded then
    if scene.init then scene:init() end
    scene.loaded = true
  end
  if scene.enter then scene:enter() end
end


function SceneManager.newScene(scene, name)
  local _scene = scene
  _scene.name = name
  _scenes[name] = _scene
end


function SceneManager.setScene(scene)
  local _scene = _scenes[scene] or nil
  if _currentScene and _currentScene.leave then _currentScene:leave() end
  _currentScene = _scene
  SceneManager.setOverlay()
  if _scene then initScene(_scene)
  elseif scene ~= nil then assert(_scene, "Scene '"..scene.."' does not exist!")
  end
end


function SceneManager.setOverlay(scene, mode)
  local _scene = _scenes[scene]
  if _overlay and _overlay.leave then _overlay:leave() end
  _overlay = _scene
  _mode = mode
  if _scene then initScene(_scene) end
end


function SceneManager.getArray(name)
  if _scenes[name] then return _scenes[name] end
end


function SceneManager.getScene()
  return _currentScene.name
end


function SceneManager.getOverlay()
  if _overlay then
    return _overlay.name
  end
end


function SceneManager.update(dt)
  if _currentScene and _mode ~= "draw" then 
    _currentScene:update(dt)
  end
  if _overlay then _overlay:update(dt) end
end


function SceneManager.draw()
  if _currentScene then _currentScene:draw() end
  if _overlay then _overlay:draw() end
end


function SceneManager.keypressed(...)
  if _overlay and _overlay.keypressed then _overlay:keypressed(...)
  elseif _currentScene and _currentScene.keypressed  then _currentScene:keypressed(...) end
end


function SceneManager.keyreleased(...)
  if _overlay and _overlay.keyreleased then _overlay:keyreleased(...)
  elseif _currentScene and _currentScene.keyreleased then _currentScene:keyreleased(...) end
end


function SceneManager.mousepressed(...)
  if _overlay and _overlay.mousepressed then _overlay:mousepressed(...)
  elseif _currentScene and _currentScene.mousepressed then _currentScene:mousepressed(...) end
end


function SceneManager.mousereleased(...)
  if _overlay and _overlay.mousereleased then _overlay:mousereleased(...)
  elseif _currentScene and _currentScene.mousereleased then _currentScene:mousereleased(...) end
end


function SceneManager.joystickpressed(...)
  if _overlay and _overlay.joystickpressed then _overlay:joystickpressed(...)
  elseif _currentScene and _currentScene.joystickpressed then _currentScene:joystickpressed(...) end
end


function SceneManager.joystickreleased(...)
  if _overlay and _overlay.joystickreleased then _overlay:joystickreleased(...)
  elseif _currentScene and _currentScene.joystickreleased then _currentScene:joystickreleased(...) end
end


function SceneManager.joystickaxis(...)
  if _overlay and _overlay.joystickaxis then _overlay:joystickaxis(...)
  elseif _currentScene and _currentScene.joystickaxis then _currentScene:joystickaxis(...) end
end

return SceneManager
