-- Mainmenu Scene --
--------------------
local SettingsScene = {}
local sounds = {
  nextButton = love.audio.newSource("assets/nextButton.ogg", "static")
  }
local SceneManager = require("source.SceneManager")
local ButtonManager = require("source.ButtonManager")
local Fader = require("source.Fader")


function SettingsScene:init()
  -- Create ButtonManager --
  self.buttonManager = ButtonManager:new()
end


function SettingsScene:enter()
  
  -- Button Functions --
  ----------------------
  local scaleFunction = function(key)
    if key then
      if key == "left" then
        if SCREENMULTIPLIER > 2 then SCREENMULTIPLIER = SCREENMULTIPLIER-1
        else SCREENMULTIPLIER = 4 end
      end
      if key == "right" then
        if SCREENMULTIPLIER < 4 then SCREENMULTIPLIER = SCREENMULTIPLIER+1
        else SCREENMULTIPLIER = 2 end
      end
    else
      if SCREENMULTIPLIER < 4 then
        SCREENMULTIPLIER = SCREENMULTIPLIER+1
      else
        SCREENMULTIPLIER = 2
      end
    end
    self:enter()
    setWindow()
  end
  
  local fullscreenFunction = function(key)
    FULLSCREEN = not FULLSCREEN
    if FULLSCREEN then SCREENMULTIPLIER = 4
    else SCREENMULTIPLIER = 3 end
    self:enter()
    setWindow()
  end
  
  local volumeFunction = function(key)
    if key then
      if key == "right" then
        if VOLUME*100 < 90 then VOLUME = VOLUME+1/10
        else VOLUME = 0 end
      elseif key == "left" then
        if VOLUME*100 > 20 then VOLUME = VOLUME-1/10
        else VOLUME = 1 end
      end
    else  
      if VOLUME*100 < 90 then VOLUME = VOLUME + 1/10
      else VOLUME = 0 end
    end
    love.audio.setVolume(VOLUME)
    sounds.nextButton:stop()
    sounds.nextButton:play()
    self:enter()
  end
  
  local vsyncFunction = function(key)
    VSYNC = not VSYNC
    self:enter()
    setWindow()
  end
  
  local backFunction = function()
    SceneManager.setScene("MenuScene")
  end
  
  -- Create Buttons --
  --------------------
  self.buttonManager:clear()
  self.buttonManager:newButton("Scale: "..SCREENMULTIPLIER, WIDTH / 2, HEIGHT / 2, scaleFunction)
  self.buttonManager:newButton("Fullscreen:"..tostring(FULLSCREEN), WIDTH / 2, HEIGHT / 2 + 10*1, fullscreenFunction)
  self.buttonManager:newButton("Volume: "..VOLUME*100, WIDTH / 2, HEIGHT / 2 + 10*2, volumeFunction)
  self.buttonManager:newButton("Vsync:"..tostring(VSYNC), WIDTH / 2, HEIGHT / 2 + 10*3, vsyncFunction)
  self.buttonManager:newButton("Back", WIDTH / 2, HEIGHT / 2 + 10*4, backFunction)
end


function SettingsScene:leave()
  SceneManager.getArray("MenuScene"):renderCanvas(true)
  self.buttonManager:setSelected(1)
end


function SettingsScene:update(dt)
  self.buttonManager:update(dt)
end


function SettingsScene:draw()
  self.buttonManager:draw()
end


function SettingsScene:keypressed(key)
  if key == "up" then self.buttonManager:itemUp()
  elseif key == "down" then self.buttonManager:itemDown()
  elseif key == "left" then self.buttonManager:itemAction("left")
  elseif key == "right" then self.buttonManager:itemAction("right") end
  if key == "escape" then SceneManager.setScene("MenuScene") end
  if key == "return" then self.buttonManager:itemAction() end
end


function SettingsScene:joystickpressed(joystick, button)
  if CONTROLLER[1]:isGamepadDown("b") then SceneManager.setScene("MenuScene")
  elseif CONTROLLER[1]:isGamepadDown("a") then self.buttonManager:itemAction()
  elseif CONTROLLER[1]:isGamepadDown("dpup") then self.buttonManager:itemUp()
  elseif CONTROLLER[1]:isGamepadDown("dpdown") then self.buttonManager:itemDown()
  elseif CONTROLLER[1]:isGamepadDown("dpleft") then self.buttonManager:itemAction("left")
  elseif CONTROLLER[1]:isGamepadDown("dpright") then self.buttonManager:itemAction("right") end
end

return SettingsScene
