

-- UI Class --
--------------
local Ui = {}
local fuelbar
local destIndicator, moneyIndicator, lifeIndicator

local Level = require("source.Level")
local passenger

function Ui:init()
  -- Fuel --
  ----------
  fuelbar = {}
  fuelbar.image = love.graphics.newImage("assets/hudFuel.png")
  fuelbar.w = fuelbar.image:getWidth()
  fuelbar.h = fuelbar.image:getHeight()
  fuelbar.x = WIDTH / 2 - fuelbar.w / 2
  fuelbar.y = HEIGHT - 13
  fuelbar.value = player.fuel
  fuelbar.length = 0
  
  function fuelbar:draw()
    self.value = player.fuel
    self.length = self.value / 100 * self.w
    if player.fuel < 20 then love.graphics.setColor(200, 50, 50) end
    love.graphics.rectangle("fill", self.x + 2, self.y + 3, self.length-5,self.h - 3)
    love.graphics.setColor(255, 255, 255)
    love.graphics.draw(self.image, self.x, self.y+1.5)
    printFontCentered(FONT.small, "Fuel", self.x, self.y - 3, self.w)
  end
  
  -- Destination Indicator --
  ---------------------------
  destIndicator = {}
  destIndicator.x = WIDTH / 2 + 20
  destIndicator.y = HEIGHT - 12

  function destIndicator:draw()
      printFontCentered(FONT.small, "Station", self.x + 38, self.y - 4, FONT.small:getWidth("Station"))
      if passenger then 
        love.graphics.setColor(50, 150, 200)
        printFontCentered(FONT.small, passenger.destination.id, self.x+38, self.y+4, FONT.small:getWidth("Station"))
        love.graphics.setColor(255, 255, 255)
      else
        love.graphics.setColor(50, 150, 200)
        printFontCentered(FONT.small, "x", self.x+38, self.y+4, FONT.small:getWidth("Station")) 
        love.graphics.setColor(255, 255, 255)
      end
  end
  
  -- Lifes --
  -----------
  lifeIndicator = {}
  lifeIndicator.image = love.graphics.newImage("assets/taxiIcon.png")
  lifeIndicator.w = lifeIndicator.image:getWidth()
  lifeIndicator.h = lifeIndicator.image:getHeight()
  lifeIndicator.x = WIDTH - 64
  lifeIndicator.y = HEIGHT - 12

  function lifeIndicator:draw()
    lifeIndicator.lives = player.lives
    printFontCentered(FONT.small, "Lives", self.x + 21, self.y - 4, FONT.small:getWidth("Lives"))
    for i = 1, lifeIndicator.lives do
      love.graphics.draw(self.image, self.x + (i*10), self.y + 4)
    end
  end
  
  -- Money --
  -----------
  moneyIndicator = {}
  moneyIndicator.x = 16
  moneyIndicator.y = HEIGHT - 12

  function moneyIndicator:draw()
    printFontCentered(FONT.small, "Money", self.x, self.y - 4, FONT.small:getWidth("Money"))
    printFont(FONT.small, math.floor(player.money).."$", self.x - 7, self.y)
    local lastPassenger = Level:getPassenger(Level.lastPassenger)
    if lastPassenger then
      love.graphics.setColor(50, 150, 200)
      printFont(FONT.small, math.floor(lastPassenger.money).."$", self.x + 18, self.y)
      love.graphics.setColor(255, 255, 255)
    else
      love.graphics.setColor(50, 150, 200)
      printFont(FONT.small, "0$", self.x + 30, self.y)
      love.graphics.setColor(255, 255, 255)
    end
  end

end


function Ui:update(dt)
end


function Ui:draw()
  love.graphics.setColor(0, 0, 0)
  love.graphics.rectangle("fill", 0, HEIGHT-21, WIDTH, 21)
  love.graphics.setColor(255, 255, 255)
  if player.passengerId then passenger = Level:getPassenger(player.passengerId)
  else passenger = nil end
  fuelbar:draw()
  destIndicator:draw()
  lifeIndicator:draw()
  moneyIndicator:draw()
end

return Ui
